---

title: README
---Gdptools Pygeoapi Plugin
========================

[![PyPI](https://img.shields.io/pypi/v/gdptools-pygeoapi-plugin.svg)](https://pypi.org/project/gdptools-pygeoapi-plugin/)
[![Status](https://img.shields.io/pypi/status/gdptools-pygeoapi-plugin.svg)](https://pypi.org/project/gdptools-pygeoapi-plugin/)
[![Python Version](https://img.shields.io/pypi/pyversions/gdptools-pygeoapi-plugin)](https://pypi.org/project/gdptools-pygeoapi-plugin)
[![License](https://img.shields.io/pypi/l/gdptools-pygeoapi-plugin)](https://creativecommons.org/publicdomain/zero/1.0/legalcode)

[![Read the documentation at https://gdptools-pygeoapi-plugin.readthedocs.io/](https://img.shields.io/readthedocs/gdptools-pygeoapi-plugin/latest.svg?label=Read%20the%20Docs)](https://gdptools-pygeoapi-plugin.readthedocs.io/)
[![Tests](https://code.usgs.gov/wma/nhgf/toolsteam/gdptools-pygeoapi-plugin/workflows/Tests/badge.svg)](https://code.usgs.gov/wma/nhgf/toolsteam/gdptools-pygeoapi-plugin/actions?workflow=Tests)
[![Codecov](https://codecov.io/gh/wma/nhgf/toolsteam/gdptools-pygeoapi-plugin/branch/main/graph/badge.svg)](https://codecov.io/gh/wma/nhgf/toolsteam/gdptools-pygeoapi-plugin)

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://code.usgs.gov/pre-commit/pre-commit)
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://code.usgs.gov/psf/black)
[![Poetry](https://img.shields.io/badge/poetry-enabled-blue)](https://python-poetry.org/)
[![Conda](https://img.shields.io/badge/conda-enabled-green)](https://anaconda.org/)

# Features

- TODO

# Requirements

- TODO

# Installation

You can install _Gdptools Pygeoapi Plugin_ via [pip](https://pip.pypa.io/) from [PyPI](https://pypi.org/):

        pip install gdptools-pygeoapi-plugin

# Usage

Please see the [Command-line Reference](Usage_) for details.

# Contributing

Contributions are very welcome. To learn more, see the Contributor Guide\_.

# License

Distributed under the terms of the [CC0 1.0 Universal license](https://creativecommons.org/publicdomain/zero/1.0/legalcode), _Gdptools Pygeoapi Plugin_ is free and open source software.

# Issues

If you encounter any problems, please [file an issue](https://code.usgs.gov/wma/nhgf/toolsteam/gdptools-pygeoapi-plugin/issues) along with a detailed description.

# Credits

This project was generated from [@chill](https://code.usgs.gov/chill)'s [Pygeoapi Plugin Cookiecutter](https://code.usgs.gov/wma/nhgf/pygeoapi-plugin-cookiecutter) template.
